==> openvdb-12.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/PrincipalComponentAnalysisImpl_8h.js <==
var PrincipalComponentAnalysisImpl_8h =
[
    [ "NoTimer", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1NoTimer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1NoTimer" ],
    [ "PcaTimer", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTimer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTimer" ],
    [ "AttrIndices", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1AttrIndices.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1AttrIndices" ],
    [ "PcaTransfer< PointDataTreeT >", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTransfer" ],
    [ "WeightPosSumsTransfer< PointDataTreeT >", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1WeightPosSumsTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1WeightPosSumsTransfer" ],
    [ "CovarianceTransfer< PointDataTreeT >", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1CovarianceTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1CovarianceTransfer" ],
    [ "OPENVDB_PCA_SELF_CONTRIBUTION", "PrincipalComponentAnalysisImpl_8h.html#a4614fc63143e1bdff7da82088c5275b8", null ],
    [ "openvdb::v12_1::points::pca_internal::GroupIndexT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a39a6b84fbe901cd11124db01ed852617", null ],
    [ "openvdb::v12_1::points::pca_internal::TimerT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a1c433791efd193de40ccd1e7bdb9ea95", null ],
    [ "openvdb::v12_1::points::pca_internal::WeightedPositionSumT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#aef0dd7cd7a370c4e165eb525ba4293e4", null ],
    [ "openvdb::v12_1::points::pca_internal::WeightSumT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a18f7ed305c5f923b88fdd66718cbb679", null ],
    [ "openvdb::v12_1::points::pca_internal::decomposeSymmetricMatrix", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#ab39298f29776d6dbd277ab308bfdf74f", null ],
    [ "openvdb::v12_1::points::pca_internal::descendingOrder", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a1ce1ef2bbf3d727bc2c490003b753738", null ],
    [ "openvdb::v12_1::points::pca_internal::initPcaArrayAttribute", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a322691f62222487fdaba847d3cf8eb13", null ],
    [ "openvdb::v12_1::points::pca", "namespaceopenvdb_1_1v12__1_1_1points.html#a74fa733452dea2d0ee1d99c9583fd30d", null ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/PrincipalComponentAnalysisImpl_8h.js <==
var PrincipalComponentAnalysisImpl_8h =
[
    [ "NoTimer", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1NoTimer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1NoTimer" ],
    [ "PcaTimer", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTimer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTimer" ],
    [ "AttrIndices", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1AttrIndices.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1AttrIndices" ],
    [ "PcaTransfer&lt; PointDataTreeT &gt;", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1PcaTransfer" ],
    [ "WeightPosSumsTransfer&lt; PointDataTreeT &gt;", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1WeightPosSumsTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1WeightPosSumsTransfer" ],
    [ "CovarianceTransfer&lt; PointDataTreeT &gt;", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1CovarianceTransfer.html", "structopenvdb_1_1v12__1_1_1points_1_1pca__internal_1_1CovarianceTransfer" ],
    [ "OPENVDB_PCA_SELF_CONTRIBUTION", "PrincipalComponentAnalysisImpl_8h.html#a4614fc63143e1bdff7da82088c5275b8", null ],
    [ "openvdb::v12_1::points::pca_internal::GroupIndexT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a39a6b84fbe901cd11124db01ed852617", null ],
    [ "openvdb::v12_1::points::pca_internal::TimerT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a1c433791efd193de40ccd1e7bdb9ea95", null ],
    [ "openvdb::v12_1::points::pca_internal::WeightedPositionSumT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#aef0dd7cd7a370c4e165eb525ba4293e4", null ],
    [ "openvdb::v12_1::points::pca_internal::WeightSumT", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a18f7ed305c5f923b88fdd66718cbb679", null ],
    [ "openvdb::v12_1::points::pca_internal::decomposeSymmetricMatrix", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#ab39298f29776d6dbd277ab308bfdf74f", null ],
    [ "openvdb::v12_1::points::pca_internal::descendingOrder", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a1ce1ef2bbf3d727bc2c490003b753738", null ],
    [ "openvdb::v12_1::points::pca_internal::initPcaArrayAttribute", "namespaceopenvdb_1_1v12__1_1_1points_1_1pca__internal.html#a322691f62222487fdaba847d3cf8eb13", null ],
    [ "openvdb::v12_1::points::pca", "namespaceopenvdb_1_1v12__1_1_1points.html#a74fa733452dea2d0ee1d99c9583fd30d", null ]
];
